'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
function requestToFetchOptions(reqOpts) {
    const options = Object.assign({}, reqOpts.headers && { headers: reqOpts.headers }, reqOpts.method && { method: reqOpts.method }, reqOpts.json && { body: JSON.stringify(reqOpts.json) });
    let uri = reqOpts.uri;
    if (reqOpts.useQuerystring === true) {
        const qs = require('querystring');
        const params = qs.stringify(reqOpts.qs);
        uri = uri + '?' + params;
    }
    return [uri, options];
}
function fetchToRequestResponse(res) {
    const response = {
        statusCode: res.status,
        statusMessage: res.statusText,
    };
    return response;
}
function teenyRequest(reqOpts, callback) {
    reqOpts.timeout = reqOpts.timeout || 60000;
    reqOpts.gzip = reqOpts.gzip || true;
    reqOpts.forever = reqOpts.forever || true;
    if (!reqOpts.pool) {
        reqOpts.pool = {};
    }
    reqOpts.pool.maxSockets = reqOpts.pool.maxSockets || Infinity;
    const [uri, options] = requestToFetchOptions(reqOpts);
    node_fetch_1.default(uri, options)
        .then((res) => {
        if (!res.ok) {
            callback(new Error(`${res.status}: ${res.statusText}`));
            return;
        }
        res.json().then(json => {
            let response = fetchToRequestResponse(res);
            response.body = json;
            callback(null, response, json);
        }).catch((err) => {
            callback(err);
        });
    });
}
exports.teenyRequest = teenyRequest;
//# sourceMappingURL=index.js.map